import requests


class PublicationClient:
    headers = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
                             "Chrome/54.0.2840.99 Safari/537.36"}
    listUrl = "https://www.omicsdi.org:443/ws/publication/list"

    def __init__(self):
        pass

    def get_list(self, acc):
        res = requests.get(self.listUrl, params={"acc": acc}, headers=self.headers)
        return res




import requests


class EnrichmentClient:
    headers = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
                             "Chrome/54.0.2840.99 Safari/537.36"}
    getSynonymsForDatasetUrl = "https://www.omicsdi.org:443/ws/enrichment/getSynonymsForDataset"
    getReanalysisUrl = "https://www.omicsdi.org:443/ws/enrichment/getSynonymsForDataset"
    getEnrichmentInfoUrl = "https://www.omicsdi.org:443/ws/enrichment/getEnrichmentInfo"
    getSimilarDatasetsByBiologicalDataUrl = "https://www.omicsdi.org:443/ws/enrichment" \
                                            "/getSimilarDatasetsByBiologicalData "
    getSimilarityInfoUrl = "https://www.omicsdi.org:443/ws/enrichment/getSimilarityInfo"

    def __init__(self):
        pass

    def get_synonyms_for_dataset(self, accession, database):
        res = requests.get(self.getSynonymsForDatasetUrl, params={
            "accession": accession,
            "database": database
        }, headers=self.headers)
        return res

    def get_reanalysis(self):
        res = requests.get(self.getReanalysisUrl, headers=self.headers)
        return res

    def get_enrichment_info(self, accession, database):
        res = requests.get(self.getEnrichmentInfoUrl, params={
            "accession": accession,
            "database": database
        }, headers=self.headers)
        return res

    def get_similar_datasets_by_biological_data(self, accession, database):
        res = requests.get(self.getSimilarDatasetsByBiologicalDataUrl, params={
            "accession": accession,
            "database": database
        }, headers=self.headers)
        return res

    def get_similarity_info(self, accession, database, threshold):
        res = requests.get(self.getSimilarityInfoUrl, params={
            "accession": accession,
            "database": database,
            "threshold": threshold
        }, headers=self.headers)
        return res



import requests


class DatabaseClient:
    headers = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
                             "Chrome/54.0.2840.99 Safari/537.36"}
    baseDatabaseUrl = "https://www.omicsdi.org:443/ws/database"
    getDatabaseAllUrl = "https://www.omicsdi.org:443/ws/database/all"
    getDatabasePicbytesUrl = "https://www.omicsdi.org:443/ws/database/db/picturebyte"

    def __init__(self):
        pass

    def get_database_pic(self, database_name):
        res = requests.get(self.baseDatabaseUrl + "/" + database_name + "/picture",  headers=self.headers)
        return res

    def get_database_all(self):
        res = requests.get(self.getDatabaseAllUrl,  headers=self.headers)
        return res

    def get_database_db_picturebyte(self):
        res = requests.get(self.getDatabasePicbytesUrl, headers=self.headers)
        return res



import requests


class SeoClient:
    headers = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
                             "Chrome/54.0.2840.99 Safari/537.36"}
    seoHomeUrl = "https://www.omicsdi.org:443/ws/seo/home"
    seoSearchUrl = "https://www.omicsdi.org:443/ws/seo/search"
    seoApiUrl = "https://www.omicsdi.org:443/ws/seo/api"
    seoSchemaUrl = "https://www.omicsdi.org:443/ws/seo/schema"
    seoDatabaseUrl = "https://www.omicsdi.org:443/ws/seo/database"
    seoDatasetUrl = "https://www.omicsdi.org:443/ws/seo/dataset"
    seoAboutUrl = "https://www.omicsdi.org:443/ws/seo/about"

    def __init__(self):
        pass

    def get_seo_home(self):
        res = requests.get(self.seoHomeUrl, headers=self.headers)
        return res

    def get_seo_search(self):
        res = requests.get(self.seoSearchUrl, headers=self.headers)
        return res

    def get_seo_api(self):
        res = requests.get(self.seoApiUrl, headers=self.headers)
        return res

    def get_seo_schema(self, acc, domain):
        res = requests.get(self.seoSchemaUrl + "/" + domain + "/" + acc, headers=self.headers)
        return res

    def get_seo_database(self):
        res = requests.get(self.seoDatabaseUrl, headers=self.headers)
        return res

    def get_seo_dataset(self, domain, acc):
        res = requests.get(self.seoDatasetUrl + "/" + domain + "/" + acc, headers=self.headers)
        return res

    def get_seo_about(self):
        res = requests.get(self.seoAboutUrl, headers=self.headers)
        return res




import requests


class DbLuceneMappingClient:
    headers = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
                             "Chrome/54.0.2840.99 Safari/537.36"}
    saveMappingUrl = "https://www.omicsdi.org:443/ws/dblucene/saveMapping"
    getLuceneNameUrl = "https://www.omicsdi.org:443/ws/dblucene/getLuceneName"
    getAllMappingsUrl = "https://www.omicsdi.org:443/ws/dblucene/getAllMappings"
    getDbNameUrl = "https://www.omicsdi.org:443/ws/dblucene/getDbName"

    def __init__(self):
        pass

    def save_mapping(self, _id, db_url, logo_path, db_name, lucene_name, description, display_name):
        res = requests.put(self.saveMappingUrl, params={
            "id": _id,
            "dbUrl": db_url,
            "logoPath": logo_path,
            "dbName": db_name,
            "luceneName": lucene_name,
            "description": description,
            "displayName": display_name
        }, headers=self.headers)
        return res

    def get_lucene_name(self, db_name):
        res = requests.get(self.getLuceneNameUrl, params={
            "dbName": db_name
        }, headers=self.headers)
        return res

    def get_all_mappings(self):
        res = requests.get(self.getAllMappingsUrl, headers=self.headers)
        return res

    def get_db_name(self, lucene_name):
        res = requests.get(self.getDbNameUrl, params={
            "luceneName": lucene_name
        }, headers=self.headers)
        return res



import requests


class FeedbackClient:
    headers = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
                             "Chrome/54.0.2840.99 Safari/537.36"}
    feedbackUrl = "https://www.omicsdi.org:443/ws/feedback/saveFeedback"
    getAllFeedbacksUrl = "https://www.omicsdi.org:443/ws/feedback/getAllFeedbacks"
    getFeedbackByStatusUrl = "https://www.omicsdi.org:443/ws/feedback/getFeedbackByStatus"

    def __init__(self):
        pass

    def save_feedback(self, searchQuery, satisfied, message, id, userInfo):
        request_params = {
            "searchQuery": searchQuery,
            "satisfied": satisfied,
            "message": message,
            "id": {
                "timeSecond": id.timeSecond,
                "inc": id.inc,
                "machine": id.machine,
                "time": id.time,
                "date": id.date,
                "timestamp": id.timestamp,
                "new": id.new
            },
            "userInfo": userInfo
        }
        res = requests.put(self.feedbackUrl, params=request_params, headers=self.headers)
        return res

    def get_all_feedbacks(self):
        res = requests.get(self.getAllFeedbacksUrl, headers=self.headers)
        return res

    def get_all_feedbacks_by_status(self, is_satisfied):
        res = requests.get(self.getFeedbackByStatusUrl, params={"isSatisfied": is_satisfied}, headers=self.headers)
        return res



from setuptools import setup, find_packages

setup(
    name="ddipy",
    version="0.0.1",
    keywords=["pip", "omicsDI", "WS-client"],
    py_modules=["ddipy"],
    description="web-service client of omicsDI API",
    license="MIT Licence",
    url="https://github.com/OmicsDI/Pyddi",
    author="Xpon",
    author_email="hll3939092@gmail.com",
    packages=find_packages(),
    include_package_data=True,
    platforms="any",
    install_requires=["requests"]
)



import requests


class TermClient:
    headers = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
                             "Chrome/54.0.2840.99 Safari/537.36"}
    getTermByPatternUrl = "https://www.omicsdi.org:443/ws/term/getTermByPattern"
    getFrequentlyTermListUrl = "https://www.omicsdi.org:443/ws/term/frequentlyTerm/list"

    def __init__(self):
        pass

    def get_term_by_pattern(self, q, size):
        res = requests.get(self.getTermByPatternUrl, params={
            "q": q,
            "size": size
        }, headers=self.headers)
        return res

    def get_term_frequently_term_list(self, size, domain, field):
        res = requests.get(self.getFrequentlyTermListUrl, params={
            "size": size,
            "domain": domain,
            "field": field
        }, headers=self.headers)
        return res



import requests


class StatisticsClient:
    headers = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
                             "Chrome/54.0.2840.99 Safari/537.36"}
    getStatisticsOrganismsUrl = "https://www.omicsdi.org:443/ws/statistics/organisms"
    getStatisticsTissuesUrl = "https://www.omicsdi.org:443/ws/statistics/tissues"
    getStatisticsOmicsUrl = "https://www.omicsdi.org:443/ws/statistics/omics"
    getStatisticsVersionUrl = "https://www.omicsdi.org:443/ws/statistics/version"
    getStatisticsDiseasesUrl = "https://www.omicsdi.org:443/ws/statistics/diseases"
    getStatisticsDomainsUrl = "https://www.omicsdi.org:443/ws/statistics/domains"
    getStatisticsOmicsByYearUrl = "https://www.omicsdi.org:443/ws/statistics/omicsByYear"
    getStatisticsGeneralUrl = "https://www.omicsdi.org:443/ws/statistics/general"

    def __init__(self):
        pass

    def get_statistics_organisms(self, size):
        res = requests.get(self.getStatisticsOrganismsUrl, params={
            "size": size
        }, headers=self.headers)
        return res

    def get_statistics_tissues(self, size):
        res = requests.get(self.getStatisticsTissuesUrl, params={
            "size": size
        }, headers=self.headers)
        return res

    def get_statistics_omics(self):
        res = requests.get(self.getStatisticsOmicsUrl, headers=self.headers)
        return res

    def get_statistics_version(self):
        res = requests.get(self.getStatisticsVersionUrl, headers=self.headers)
        return res

    def get_statistics_diseases(self, size):
        res = requests.get(self.getStatisticsDiseasesUrl, params={
            "size": size
        }, headers=self.headers)
        return res

    def get_statistics_domains(self):
        res = requests.get(self.getStatisticsDomainsUrl, headers=self.headers)
        return res

    def get_statistics_omics_by_year(self):
        res = requests.get(self.getStatisticsOmicsByYearUrl, headers=self.headers)
        return res

    def get_statistics_general(self):
        res = requests.get(self.getStatisticsGeneralUrl, headers=self.headers)
        return res






import requests


class DatasetClient:
    headers = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
                             "Chrome/54.0.2840.99 Safari/537.36"}
    baseDatasetUrl = "https://www.omicsdi.org:443/ws/dataset"
    mergeUrl = "https://www.omicsdi.org:443/ws/dataset/merge"
    getDatasetPageUrl = "https://www.omicsdi.org:443/ws/dataset/getDatasetPage"
    unmergeUrl = "https://www.omicsdi.org:443/ws/dataset/unmerge"
    getMergeCandidatesUrl = "https://www.omicsdi.org:443/ws/dataset/getMergeCandidates"
    multiomicsMergeUrl = "https://www.omicsdi.org:443/ws/dataset/multiomicsMerge"
    getAllmergedUrl = "https://www.omicsdi.org:443/ws/dataset/getAllmerged"
    getDatasetByUrlUrl = "https://www.omicsdi.org:443/ws/dataset/getDatasetByUrl"
    getAllUrl = "https://www.omicsdi.org:443/ws/dataset/getAll"
    getMergeCandidateCountUrl = "https://www.omicsdi.org:443/ws/dataset/getMergeCandidateCount"
    skipMergeUrl = "https://www.omicsdi.org:443/ws/dataset/skipMerge"
    getDbDatasetCountUrl = "https://www.omicsdi.org:443/ws/dataset/getDbDatasetCount"
    searchUrl = "https://www.omicsdi.org:443/ws/dataset/search"
    latestUrl = "https://www.omicsdi.org:443/ws/dataset/latest"
    getUrl = "https://www.omicsdi.org:443/ws/dataset/get"
    getSimilarByPubmedUrl = "https://www.omicsdi.org:443/ws/dataset/getSimilarByPubmed"
    batchUrl = "https://www.omicsdi.org:443/ws/dataset/batch"
    mostAccessedUrl = "https://www.omicsdi.org:443/ws/dataset/mostAccessed"
    getFileLinksUrl = "https://www.omicsdi.org:443/ws/dataset/getFileLinks"
    getSimilarUrl = "https://www.omicsdi.org:443/ws/dataset/getSimilar"

    def __init__(self):
        pass

    def merge(self, similar_arr, accession, database, source_url, name, access_token):
        similar_list = []
        for similar in similar_arr:
            temp_dict = {}
            temp_dict.update(accession=similar.accession)
            temp_dict.update(database=similar.database)
            temp_dict.update(sourceUrl=similar.sourceUrl)
            temp_dict.update(name=similar.name)
            similar_list.append(temp_dict)

        request_params = {
            "similars": similar_list,
            "accession": accession,
            "database": database,
            "sourceUrl": source_url,
            "name": name
        }
        tokened_header = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, "
                                        "like Gecko) "
                                        "Chrome/54.0.2840.99 Safari/537.36",
                          "x-auth-token": access_token}
        res = requests.post(self.mergeUrl, params=request_params, headers=tokened_header)
        return res

    def get_dataset_page(self, start, size):
        res = requests.get(self.getDatasetPageUrl, params={
            "start": start,
            "size": size
        }, headers=self.headers)
        return res

    # todo
    def unmerge(self, merge_candidates, access_token):
        tokened_header = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, "
                                        "like Gecko) "
                                        "Chrome/54.0.2840.99 Safari/537.36",
                          "x-auth-token": access_token}
        res = requests.post(self.unmergeUrl, params=merge_candidates, headers=tokened_header)
        return res

    def get_merge_candidates(self, start, size, access_token):
        tokened_header = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, "
                                        "like Gecko) "
                                        "Chrome/54.0.2840.99 Safari/537.36",
                          "x-auth-token": access_token}
        res = requests.get(self.getMergeCandidatesUrl, params={
            "start": start,
            "size": size
        }, headers=tokened_header)
        return res

    def multiomics_merge(self, similar_arr, accession, database, source_url, name, access_token):
        similar_list = []
        for similar in similar_arr:
            temp_dict = {}
            temp_dict.update(accession=similar.accession)
            temp_dict.update(database=similar.database)
            temp_dict.update(sourceUrl=similar.sourceUrl)
            temp_dict.update(name=similar.name)
            similar_list.append(temp_dict)

        request_params = {
            "similars": similar_list,
            "accession": accession,
            "database": database,
            "sourceUrl": source_url,
            "name": name
        }
        tokened_header = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, "
                                        "like Gecko) "
                                        "Chrome/54.0.2840.99 Safari/537.36",
                          "x-auth-token": access_token}
        res = requests.post(self.multiomicsMergeUrl, params=request_params, headers=tokened_header)
        return res

    def get_allmerged(self, access_token):
        tokened_header = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, "
                                        "like Gecko) "
                                        "Chrome/54.0.2840.99 Safari/537.36",
                          "x-auth-token": access_token}
        res = requests.get(self.getAllmergedUrl, headers=tokened_header)
        return res

    def get_dataset_by_url(self, url):
        res = requests.post(self.getDatasetByUrlUrl, params={
            "url": url
        }, headers=self.headers)
        return res

    def get_all(self):
        res = requests.get(self.getAllUrl, headers=self.headers)
        return res

    def get_merge_candidate_count(self, access_token):
        tokened_header = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, "
                                        "like Gecko) "
                                        "Chrome/54.0.2840.99 Safari/537.36",
                          "x-auth-token": access_token}
        res = requests.get(self.getMergeCandidateCountUrl, headers=tokened_header)
        return res

    def skip_merge(self, similar_arr, accession, database, source_url, name, access_token):
        similar_list = []
        for similar in similar_arr:
            temp_dict = {}
            temp_dict.update(accession=similar.accession)
            temp_dict.update(database=similar.database)
            temp_dict.update(sourceUrl=similar.sourceUrl)
            temp_dict.update(name=similar.name)
            similar_list.append(temp_dict)

        request_params = {
            "similars": similar_list,
            "accession": accession,
            "database": database,
            "sourceUrl": source_url,
            "name": name
        }
        tokened_header = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, "
                                        "like Gecko) "
                                        "Chrome/54.0.2840.99 Safari/537.36",
                          "x-auth-token": access_token}
        res = requests.post(self.skipMergeUrl, params=request_params, headers=tokened_header)
        return res

    def get_dataset_from_domain_and_accession(self, domain, accession, debug):
        res = requests.get(self.baseDatasetUrl + "/" + domain + "/" + accession, params={
            "debug": debug
        }, headers=self.headers)
        return res

    def get_dataset_files_from_domain_and_accession(self, domain, accession, position):
        res = requests.get(self.baseDatasetUrl + "/" + domain + "/" + accession + "/files",
                           params={
                               "position": position
                           },
                           headers=self.headers)
        return res

    def get_db_dataset_count(self):
        res = requests.get(self.getDbDatasetCountUrl, headers=self.headers)
        return res

    def search(self, query, sortfield, order, start, size, faceCount):
        res = requests.get(self.searchUrl, params={
            "query": query,
            "sortfield": sortfield,
            "order": order,
            "start": start,
            "size": size,
            "faceCount": faceCount
        }, headers=self.headers)
        return res

    def latest(self, size):
        res = requests.get(self.latestUrl, params={
            "size": size
        }, headers=self.headers)
        return res

    def get(self, acc, database):
        res = requests.get(self.getUrl, params={
            "acc": acc,
            "database": database
        }, headers=self.headers)
        return res

    def get_similar_by_pubmed(self, pubmed):
        res = requests.get(self.getSimilarByPubmedUrl, params={
            "pubmed": pubmed
        }, headers=self.headers)
        return res

    def batch(self, acc, database):
        res = requests.get(self.batchUrl, params={
            "acc": acc,
            "database": database
        }, headers=self.headers)
        return res

    def most_accessed(self, size):
        res = requests.get(self.mostAccessedUrl, params={
            "size": size
        }, headers=self.headers)
        return res

    def get_file_links(self, acc, database):
        res = requests.get(self.getFileLinksUrl, params={
            "acc": acc,
            "database": database
        }, headers=self.headers)
        return res

    def get_similar(self, acc, database):
        res = requests.get(self.getSimilarUrl, params={
            "acc": acc,
            "database": database
        }, headers=self.headers)
        return res
